@@ -1,7 +1,6 @@
-from __future__ import absolute_import, division, print_function
-
-import stripe
-from stripe.error import StripeError
+# Used for global variables
+import stripe  # noqa: IMP101
+from stripe._error import StripeError
 
 
 class OAuthError(StripeError):
@@ -18,14 +17,14 @@ class OAuthError(StripeError):
             description, http_body, http_status, json_body, headers, code
         )
 
-    def construct_error_object(self):
+    def _construct_error_object(self):
         if self.json_body is None:
             return None
 
-        return (
-            stripe.api_resources.error_object.OAuthErrorObject.construct_from(
-                self.json_body, stripe.api_key
-            )
+        return stripe.error_object.OAuthErrorObject._construct_from(  # pyright: ignore
+            values=self.json_body,
+            requestor=stripe._APIRequestor._global_instance(),
+            api_mode="V1",
         )
 
 
