@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 import stripe
 
 
@@ -7,24 +5,18 @@ class TestListableAPIResource(object):
     class MyListable(stripe.api_resources.abstract.ListableAPIResource):
         OBJECT_NAME = "mylistable"
 
-    def test_all(self, request_mock):
-        request_mock.stub_request(
+    def test_all(self, http_client_mock):
+        http_client_mock.stub_request(
             "get",
-            "/v1/mylistables",
-            {
-                "object": "list",
-                "data": [
-                    {"object": "charge", "name": "jose"},
-                    {"object": "charge", "name": "curly"},
-                ],
-                "url": "/v1/charges",
-                "has_more": False,
-            },
+            path="/v1/mylistables",
+            rbody='{"object": "list", "data": [{"object": "charge", "name": "jose"}, {"object": "charge", "name": "curly"}], "url": "/v1/charges", "has_more": false}',
             rheaders={"request-id": "req_id"},
         )
 
         res = self.MyListable.list()
-        request_mock.assert_requested("get", "/v1/mylistables", {})
+        http_client_mock.assert_requested(
+            "get", path="/v1/mylistables", query_string=""
+        )
         assert len(res.data) == 2
         assert all(isinstance(obj, stripe.Charge) for obj in res.data)
         assert res.data[0].name == "jose"
