@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 import stripe
 
 
@@ -7,9 +5,13 @@ TEST_RESOURCE_ID = "pts_123"
 
 
 class TestSession(object):
-    def test_is_creatable(self, request_mock):
+    def test_is_creatable(self, http_client_mock):
         resource = stripe.billing_portal.Session.create(
             customer="cus_123", return_url="https://stripe.com/return"
         )
-        request_mock.assert_requested("post", "/v1/billing_portal/sessions")
+        http_client_mock.assert_requested(
+            "post",
+            path="/v1/billing_portal/sessions",
+            post_data="customer=cus_123&return_url=https://stripe.com/return",
+        )
         assert isinstance(resource, stripe.billing_portal.Session)
