@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 import stripe
 
 
@@ -7,21 +5,22 @@ TEST_RESOURCE_ID = "vs_123"
 
 
 class TestVerificationReport(object):
-    def test_is_listable(self, request_mock):
+    def test_is_listable(self, http_client_mock):
         resources = stripe.identity.VerificationReport.list()
-        request_mock.assert_requested(
-            "get", "/v1/identity/verification_reports"
+        http_client_mock.assert_requested(
+            "get", path="/v1/identity/verification_reports"
         )
         assert isinstance(resources.data, list)
         assert isinstance(
             resources.data[0], stripe.identity.VerificationReport
         )
 
-    def test_is_retrievable(self, request_mock):
+    def test_is_retrievable(self, http_client_mock):
         resource = stripe.identity.VerificationReport.retrieve(
             TEST_RESOURCE_ID
         )
-        request_mock.assert_requested(
-            "get", "/v1/identity/verification_reports/%s" % TEST_RESOURCE_ID
+        http_client_mock.assert_requested(
+            "get",
+            path="/v1/identity/verification_reports/%s" % TEST_RESOURCE_ID,
         )
         assert isinstance(resource, stripe.identity.VerificationReport)
