@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 import stripe
 
 
@@ -7,7 +5,9 @@ TEST_RESOURCE_ID = "rdr_123"
 
 
 class TestConnectionToken(object):
-    def test_is_creatable(self, request_mock):
+    def test_is_creatable(self, http_client_mock):
         resource = stripe.terminal.ConnectionToken.create()
-        request_mock.assert_requested("post", "/v1/terminal/connection_tokens")
+        http_client_mock.assert_requested(
+            "post", path="/v1/terminal/connection_tokens", post_data=""
+        )
         assert isinstance(resource, stripe.terminal.ConnectionToken)
